@@ -575,7 +575,21 @@ class MacroCodeGenerator(BaseCodeGenerator):
             if idx:
                 self.writer.write(", ")
 
-            self.visit(item.key, frame)
+            # item.key should be a constant string. Otherwise how do you
+            # get to output a dictionary with a variable key string?
+            # So it is either a `Const` or `Name` node. 
+            if isinstance(item.key, jinja2.nodes.Const):
+                if "." in item.key.value:
+                    raise jinja2.compiler.TemplateAssertionError(
+                        "My templates get confused when you try and create a dictionary with a key with a dot in it.", item.key.lineno, self.name, self.filename)
+                self.writer.write(item.key.value)
+            elif isinstance(item.key, jinja2.nodes.Name):
+                self.writer.write(item.key.name)
+            else:
+                raise jinja2.compiler.TemplateAssertionError(
+                    "Dictionary keys must be constant.",
+                    item.key.lineno, self.name, self.filename)
+
             self.writer.write(": ")
             self.visit(item.value, frame)
 
